History
=======

0.2.0 (2021-10-04)
------------------

* Improved Documentation
* League specific functions
* Basic CLI using `python-fire`
* Fantasy score calculation
* Bugfixes

0.1.0 (2021-07-20)
------------------

* First release on PyPI.
